@@ -30,16 +30,16 @@
 #include "search.h"
 #include "prefs.h"
 
-#include <kdebug.h>
+#include <QDebug>
 #include <kiconloader.h>
 #include <klocale.h>
-#include <kpushbutton.h>
-#include <klineedit.h>
-#include <kstandarddirs.h>
+#include <QPushButton>
+#include <QLineEdit>
 
 #include <QTimer>
 #include <QKeyEvent>
 #include <QFile>
+#include <QStandardPaths>
 
 MolcalcWidget::MolcalcWidget(QWidget *parent) : QWidget(parent)
 {
@@ -54,7 +54,7 @@ MolcalcWidget::MolcalcWidget(QWidget *parent) : QWidget(parent)
     connect(ui.formulaEdit, SIGNAL(returnPressed()), this, SLOT(slotCalculate()));
     connect(m_timer, SIGNAL(timeout()), this, SLOT(slotCalculate()));
 
-    ui.formulaEdit->setClearButtonShown(true);
+    ui.formulaEdit->setClearButtonEnabled(true);
 
     clear();
     if (!Prefs::addAlias()) {
@@ -72,12 +72,12 @@ MolcalcWidget::MolcalcWidget(QWidget *parent) : QWidget(parent)
         int i = 0;                          // loop counter
 
         // Search in User defined aliases.
-        QString fileName = KStandardDirs::locate("data", "libkdeedu/data/symbols2.csv");
+        QString fileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "libkdeedu/data/symbols2.csv");
         QFile file(fileName);
 
         // Check file validity
         if (!(!file.open(QIODevice::ReadOnly | QIODevice::Text))) {
-            kDebug() << fileName << " opened";
+            qDebug() << fileName << " opened";
             QTextStream in(&file);
             // Get all shortForms and fullForms in the file.
             // eg the short form and full form extracted from ("Me","CH3")
@@ -102,19 +102,19 @@ MolcalcWidget::MolcalcWidget(QWidget *parent) : QWidget(parent)
                     (i18n("%1",shortForm + " : " + fullForm)));
             }
         } else {
-            kDebug() << fileName << " could not be opened!";
+            qDebug() << fileName << " could not be opened!";
         }
 
         // Find the system defined aliases
         // Open the file
-        fileName = KStandardDirs::locate("data", "libkdeedu/data/symbols.csv");
+        fileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "libkdeedu/data/symbols.csv");
         QFile file2(fileName);
         shortList.clear();
         fullList.clear();
 
         // Check file validity
         if (!(!file2.open(QIODevice::ReadOnly | QIODevice::Text))) {
-            kDebug() << fileName << " opened";
+            qDebug() << fileName << " opened";
             QTextStream in(&file2);
 
             // Get all shortForms and fullForms in the file.
@@ -138,7 +138,7 @@ MolcalcWidget::MolcalcWidget(QWidget *parent) : QWidget(parent)
                     (i18n("%1",shortForm + " : " + fullForm)));
             }
         } else {
-            kDebug() << fileName << " could not be opened!";
+            qDebug() << fileName << " could not be opened!";
         }
     }
 }
@@ -172,10 +172,10 @@ void MolcalcWidget::clear()
 
 void MolcalcWidget::updateUI()
 {
-    kDebug() << "MolcalcWidget::updateUI()";
+    qDebug() << "MolcalcWidget::updateUI()";
 
     if (m_validInput) {
-        kDebug() << "m_validInput == true";
+        qDebug() << "m_validInput == true";
 
         // The complexString stores the whole molecule like this:
         // 1 Seaborgium. Cumulative Mass: 263.119 u (39.2564 %)
@@ -231,7 +231,7 @@ void MolcalcWidget::updateUI()
         KalziumDataObject::instance()->findElements(list);
 #endif
     } else { //the input was invalid, so tell this the user
-        kDebug() << "m_validInput == false";
+        qDebug() << "m_validInput == false";
         ui.resultComposition->setText(i18n("Invalid input"));
         ui.resultLabel->setText(QString());
         ui.resultMass->setText(QString());
@@ -260,7 +260,7 @@ QString MolcalcWidget::compositionString(ElementCountMap &_map)
 
 void MolcalcWidget::slotCalculate()
 {
-    kDebug() << "MolcalcWidget::slotCalcButtonClicked()";
+    qDebug() << "MolcalcWidget::slotCalcButtonClicked()";
     QString  molecule = ui.formulaEdit->text();
 
     // Parse the molecule, and at the same time calculate the total
@@ -269,7 +269,7 @@ void MolcalcWidget::slotCalculate()
             m_validInput = m_parser->weight(molecule, &m_mass, &m_elementMap);
             m_aliasList = m_parser->aliasList();
     }
-    kDebug() << "done calculating.";
+    qDebug() << "done calculating.";
 
     updateUI();
 }
@@ -308,14 +308,14 @@ void MolcalcWidget::addAlias()
     }
 
     // Open the file to write
-    QString fileName = KStandardDirs::locate("data", "libkdeedu/data/symbols2.csv");
+    QString fileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "libkdeedu/data/symbols2.csv");
     QFile file(fileName);
 
     if (!(!file.open(QIODevice::WriteOnly| QIODevice::Append | QIODevice::Text))) {
         QTextStream out(&file);
         out << "\"" + shortForm + "\",\"" + fullForm + "\"\n";
-        kDebug() << fileName << "is the file.";
-        kDebug() << "\"" + shortForm + "\",\"" + fullForm + "\"\n";
+        qDebug() << fileName << "is the file.";
+        qDebug() << "\"" + shortForm + "\",\"" + fullForm + "\"\n";
         ui.aliasMessage->setText(i18n("done!"));
         return;
     } else {
@@ -330,4 +330,3 @@ void MolcalcWidget::hideExtra()
     ui.details->hide();
     ui.tabWidget->removeTab(1);
 }
-#include "molcalcwidget.moc"
