@@ -23,7 +23,7 @@
 #include <QPainter>
 #include <QVBoxLayout>
 
-#include <KLocale>
+#include <KLocalizedString>
 
 #include <math.h>
 
@@ -259,4 +259,3 @@ void OrbitsWidget::paintEvent(QPaintEvent*)
     }
 }
 
-#include "orbitswidget.moc"
